aboutsummaryrefslogtreecommitdiff
path: root/api/routes
diff options
context:
space:
mode:
authorkaotisk <kaotisk@arching-kaos.org>2024-02-27 07:20:27 +0200
committerkaotisk <kaotisk@arching-kaos.org>2024-02-27 07:20:27 +0200
commitfa5d6becb482da75e65683b0ae690d35fa3eade6 (patch)
tree131bae638ebcdde7179620a0b0b5153aa36b927a /api/routes
parent1da7813fe8dab6deb3bcbcfe79f4ad44c5f7fe0c (diff)
downloadarching-kaos-tools-fa5d6becb482da75e65683b0ae690d35fa3eade6.tar.gz
arching-kaos-tools-fa5d6becb482da75e65683b0ae690d35fa3eade6.tar.bz2
arching-kaos-tools-fa5d6becb482da75e65683b0ae690d35fa3eade6.zip
Refactor Arching Kaos ID to node_info
Diffstat (limited to 'api/routes')
-rw-r--r--api/routes/default/index.js2
-rw-r--r--api/routes/index.js4
2 files changed, 3 insertions, 3 deletions
diff --git a/api/routes/default/index.js b/api/routes/default/index.js
index e5db7f5..f3eb50e 100644
--- a/api/routes/default/index.js
+++ b/api/routes/default/index.js
@@ -9,7 +9,7 @@ module.exports = (req, res) => {
{gathered_zchain_zlatest_pairs:settings.DEF_PROTO+"["+settings.LOCAL_IP+"]:"+settings.PORT+settings.URL_PREFIX+"/seens"},
{node_local_chain:settings.DEF_PROTO+"["+settings.LOCAL_IP+"]:"+settings.PORT+settings.URL_PREFIX+"/chain"},
{node_local_peers:settings.DEF_PROTO+"["+settings.LOCAL_IP+"]:"+settings.PORT+settings.URL_PREFIX+"/peers"},
- {node_local_akid:settings.DEF_PROTO+"["+settings.LOCAL_IP+"]:"+settings.PORT+settings.URL_PREFIX+"/akid"},
+ {node_local_info:settings.DEF_PROTO+"["+settings.LOCAL_IP+"]:"+settings.PORT+settings.URL_PREFIX+"/node_info"},
{node_local_zlatest:settings.DEF_PROTO+"["+settings.LOCAL_IP+"]:"+settings.PORT+settings.URL_PREFIX+"/zlatest"},
{latest_known_mined_block:settings.DEF_PROTO+"["+settings.LOCAL_IP+"]:"+settings.PORT+settings.URL_PREFIX+"/slatest"},
{show_mined_block:settings.DEF_PROTO+"["+settings.LOCAL_IP+"]:"+settings.PORT+settings.URL_PREFIX+"/sblock"},
diff --git a/api/routes/index.js b/api/routes/index.js
index 3755524..174ed66 100644
--- a/api/routes/index.js
+++ b/api/routes/index.js
@@ -40,8 +40,8 @@ router.route(settings.URL_PREFIX+'/sblock/:sblock').get(getSBlock);
router.route(settings.URL_PREFIX+'/zchain').get(getZChain);
// Returns latest zblock from node's local chain
router.route(settings.URL_PREFIX+'/zlatest').get(getZLatest);
-// Returns local node's akid
-router.route(settings.URL_PREFIX+'/akid').get(getAkid);
+// Returns local node's info
+router.route(settings.URL_PREFIX+'/node_info').get(getAkid);
// Returns local node's peers
router.route(settings.URL_PREFIX+'/peers').get(getPeers);
// Returns content